@@ -17,8 +17,8 @@ from django.db import models
 from django.db import transaction
 from django.utils.translation import gettext_lazy as _
 
-from .common import DELIMITER
-from .common import serialise_model_attr
+from ..common import DELIMITER
+from ..common import serialise_model_attr
 
 LOGGER = logging.getLogger(__file__)
 
